<?php
/**
 * BdThemes Testimonials CPT
 *
 * @package BdThemes Testimonials
 * @since 1.1.1
 */

if (!class_exists('BdThemesTestimonialsCPT')) {
    class BdThemesTestimonialsCPT {

        public function __construct() {
            add_action('init', [$this, 'bdthemes_testimonial_register'], 1);
            add_action('init', [$this, 'bdthemes_testimonials_taxonomy'], 1);
            add_filter('manage_edit-bdthemes-testimonial_columns', [$this, 'bdthemes_testimonial_edit_columns']);
            add_action('manage_bdthemes-testimonial_posts_custom_column', [$this, 'bdthemes_testimonial_column_display'], 10, 2);
        }
        public function bdthemes_testimonial_register() {

            $testimonial_slug = get_theme_mod('bdthemes_testimonial_slug');

            if (isset($testimonial_slug) && $testimonial_slug != '') {
                $testimonial_slug = $testimonial_slug;
            } else {
                $testimonial_slug = 'testimonial';
            }

            $labels = array(
                'name'               => esc_html__('Testimonials', 'bdthemes-testimonials'),
                'singular_name'      => esc_html__('Testimonial', 'bdthemes-testimonials'),
                'add_new'            => esc_html__('Add New', 'bdthemes-testimonials'),
                'add_new_item'       => esc_html__('Add New Testimonial', 'bdthemes-testimonials'),
                'all_items'          => esc_html__('All Testimonials', 'bdthemes-testimonials'),
                'edit_item'          => esc_html__('Edit Testimonial', 'bdthemes-testimonials'),
                'new_item'           => esc_html__('Add New Testimonial', 'bdthemes-testimonials'),
                'view_item'          => esc_html__('View Item', 'bdthemes-testimonials'),
                'search_items'       => esc_html__('Search Testimonial', 'bdthemes-testimonials'),
                'not_found'          => esc_html__('No testimonial(s) found', 'bdthemes-testimonials'),
                'not_found_in_trash' => esc_html__('No testimonial(s) found in trash', 'bdthemes-testimonials')
            );

            $args = array(
                'labels'          => $labels,
                'public'          => true,
                'show_ui'         => true,
                'capability_type' => 'post',
                'hierarchical'    => false,
                'menu_icon'       => 'dashicons-testimonial',
                'rewrite'         => array('slug' => $testimonial_slug), // Permalinks format
                'supports'        => array('title', 'editor', 'excerpt', 'thumbnail')
            );

            add_filter('enter_title_here',  [$this, 'change_default_title']);
            register_post_type('bdthemes-testimonial', $args);
        }

        public function bdthemes_testimonials_taxonomy() {

            register_taxonomy(
                "testimonial_categories",
                array("bdthemes-testimonial"),
                array(
                    "hierarchical"   => true,
                    "label"          => "Categories",
                    "singular_label" => "Category",
                    "rewrite"        => true
                )
            );

            register_taxonomy(
                'testimonial_tag',
                'bdthemes-testimonial',
                array(
                    'hierarchical'  => false,
                    'label'         => __('Tags', 'bdthemes-testimonials'),
                    'singular_name' => __('Tag', 'bdthemes-testimonials'),
                    'rewrite'       => true,
                    'query_var'     => true
                )
            );
        }


        public function change_default_title($title) {
            $screen = get_current_screen();

            if ('bdthemes-testimonial' == $screen->post_type)
                $title = esc_html__("Enter the customer's name here", 'bdthemes-testimonials');

            return $title;
        }


        public function bdthemes_testimonial_edit_columns($testimonial_columns) {
            $testimonial_columns = array(
                "cb"                     => "<input type=\"checkbox\" />",
                "title"                  => esc_html__('Title', 'bdthemes-testimonials'),
                "thumbnail"              => esc_html__('Thumbnail', 'bdthemes-testimonials'),
                "testimonial_categories" => esc_html__('Categories', 'bdthemes-testimonials'),
                "date"                   => esc_html__('Date', 'bdthemes-testimonials'),
            );
            return $testimonial_columns;
        }

        public function bdthemes_testimonial_column_display($testimonial_columns, $post_id) {

            switch ($testimonial_columns) {

                    // Display the thumbnail in the column view
                case "thumbnail":
                    $width = (int) 64;
                    $height = (int) 64;
                    $thumbnail_id = get_post_meta($post_id, '_thumbnail_id', true);

                    // Display the featured image in the column view if possible
                    if ($thumbnail_id) {
                        $thumb = wp_get_attachment_image($thumbnail_id, array($width, $height), true);
                    }
                    if (isset($thumb)) {
                        echo $thumb; // No need to escape
                    } else {
                        echo esc_html__('None', 'bdthemes-testimonials');
                    }
                    break;

                    // Display the testimonial tags in the column view
                case "testimonial_categories":

                    if ($category_list = get_the_term_list($post_id, 'testimonial_categories', '', ', ', '')) {
                        echo $category_list; // No need to escape
                    } else {
                        echo esc_html__('None', 'bdthemes-testimonials');
                    }
                    break;
            }
        }
    }
}

new BdThemesTestimonialsCPT();
